@@ -33,9 +33,10 @@
 #  define KROSSUI_DEPRECATED_NO_EXPORT KROSSUI_NO_EXPORT KROSSUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KROSSUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KROSSUI_NO_DEPRECATED
+#    define KROSSUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
